Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2248)

Unified Diff: ash/wm/overview/window_selector.h

Issue 2895713002: [mus+ash] Removes WmWindow from ash/wm/mru_window_tracker and overview mode (Closed)
Patch Set: Address nits, unit_tests target compiles Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/wm/overview/window_selector.h
diff --git a/ash/wm/overview/window_selector.h b/ash/wm/overview/window_selector.h
index fea54f200fb31d6a2f7675c4c7cbcbe138bf7505..16e41daa5d722bd5ef1253d141e9de83e303b1d2 100644
--- a/ash/wm/overview/window_selector.h
+++ b/ash/wm/overview/window_selector.h
@@ -31,7 +31,6 @@ class WindowSelectorDelegate;
class WindowSelectorItem;
class WindowSelectorTest;
class WindowGrid;
-class WmWindow;
// The WindowSelector shows a grid of all of your windows, allowing to select
// one by clicking or tapping on it.
@@ -41,11 +40,11 @@ class ASH_EXPORT WindowSelector : public display::DisplayObserver,
public views::TextfieldController {
public:
// Returns true if the window can be selected in overview mode.
- static bool IsSelectable(WmWindow* window);
+ static bool IsSelectable(aura::Window* window);
enum Direction { LEFT, UP, RIGHT, DOWN };
- using WindowList = std::vector<WmWindow*>;
+ using WindowList = std::vector<aura::Window*>;
explicit WindowSelector(WindowSelectorDelegate* delegate);
~WindowSelector() override;
@@ -112,8 +111,8 @@ class ASH_EXPORT WindowSelector : public display::DisplayObserver,
private:
friend class WindowSelectorTest;
- // Returns the WmWindow for |text_filter_widget_|.
- WmWindow* GetTextFilterWidgetWindow();
+ // Returns the aura::Window for |text_filter_widget_|.
+ aura::Window* GetTextFilterWidgetWindow();
// Position all of the windows in the overview.
void PositionWindows(bool animate);
@@ -134,7 +133,7 @@ class ASH_EXPORT WindowSelector : public display::DisplayObserver,
void RemoveAllObservers();
// Tracks observed windows.
- std::set<WmWindow*> observed_windows_;
+ std::set<aura::Window*> observed_windows_;
// Weak pointer to the selector delegate which will be called when a
// selection is made.
@@ -143,7 +142,7 @@ class ASH_EXPORT WindowSelector : public display::DisplayObserver,
// A weak pointer to the window which was focused on beginning window
// selection. If window selection is canceled the focus should be restored to
// this window.
- WmWindow* restore_focus_window_;
+ aura::Window* restore_focus_window_;
// True when performing operations that may cause window activations. This is
// used to prevent handling the resulting expected activation.

Powered by Google App Engine
This is Rietveld 408576698